import { Strategy } from './strategy';
import { GitHub } from './github';
import { ReleaserConfig, PluginType, RepositoryConfig } from './manifest';
import { ManifestPlugin } from './plugin';
import { ChangelogNotes, ChangelogSection } from './changelog-notes';
declare const allReleaseTypes: readonly ["dart", "elixir", "go", "go-yoshi", "helm", "java-backport", "java-bom", "java-lts", "java-yoshi", "krm-blueprint", "node", "ocaml", "php", "php-yoshi", "python", "ruby", "ruby-yoshi", "rust", "simple", "terraform-module"];
export declare type ReleaseType = typeof allReleaseTypes[number];
export declare function getReleaserTypes(): readonly ReleaseType[];
export declare function getVersioningStrategyTypes(): readonly VersioningStrategyType[];
export declare function getChangelogTypes(): readonly ChangelogNotesType[];
export interface StrategyFactoryOptions extends ReleaserConfig {
    github: GitHub;
    path?: string;
    targetBranch?: string;
}
export declare function buildStrategy(options: StrategyFactoryOptions): Promise<Strategy>;
declare const allVersioningTypes: readonly ["default", "always-bump-patch", "service-pack"];
export declare type VersioningStrategyType = typeof allVersioningTypes[number];
interface PluginFactoryOptions {
    type: PluginType;
    github: GitHub;
    targetBranch: string;
    repositoryConfig: RepositoryConfig;
    alwaysLinkLocal?: boolean;
    updateAllPackages?: boolean;
}
export declare function buildPlugin(options: PluginFactoryOptions): ManifestPlugin;
declare const allChangelogNotesTypes: readonly ["default", "github"];
export declare type ChangelogNotesType = typeof allChangelogNotesTypes[number];
interface ChangelogNotesFactoryOptions {
    type: ChangelogNotesType;
    github: GitHub;
    changelogSections?: ChangelogSection[];
    commitPartial?: string;
    headerPartial?: string;
    mainTemplate?: string;
}
export declare function buildChangelogNotes(options: ChangelogNotesFactoryOptions): ChangelogNotes;
export {};
