import { GitHub } from './github';
import { CandidateReleasePullRequest, RepositoryConfig } from './manifest';
/**
 * A plugin runs after a repository manifest has built candidate
 * pull requests and can make updates that span across multiple
 * components. A plugin *might* choose to merge pull requests or add
 * or update existing files.
 */
export declare abstract class ManifestPlugin {
    readonly github: GitHub;
    readonly targetBranch: string;
    readonly repositoryConfig: RepositoryConfig;
    constructor(github: GitHub, targetBranch: string, repositoryConfig: RepositoryConfig);
    /**
     * Post-process candidate pull requests.
     * @param {CandidateReleasePullRequest[]} pullRequests Candidate pull requests
     * @returns {CandidateReleasePullRequest[]} Updated pull requests
     */
    abstract run(pullRequests: CandidateReleasePullRequest[]): Promise<CandidateReleasePullRequest[]>;
}
